@@ -42,28 +42,27 @@ create_clean_reported_cases <- function(reported_cases, horizon, zero_threshold
 #'
 #' @description `r lifecycle::badge("stable")`
 #' This functions creates a data frame of reported cases that has been smoothed using 
-#' a rolling average (with a period set by `smoothing_window`) and shifted back in time 
+#' a centred partial rolling average (with a period set by `smoothing_window`) and shifted back in time 
 #' by some delay. It is used by `estimate_infections` to generate the mean shifted prior
 #' on which the back calculation method (see `backcalc_opts`) is based.
 #' @param smoothing_window Numeric, the rolling average smoothing window
-#' to apply.
+#' to apply. Must be odd in order to be defined as a centred average.
 #' @param shift Numeric, mean delay shift to apply.
 #' @inheritParams estimate_infections
 #' @inheritParams create_stan_data
 #' @importFrom data.table copy shift frollmean fifelse .N
 #' @importFrom stats lm
+#' @importFrom runner mean_run
 #' @return A data frame for shifted reported cases
 #' @export
 #' @examples
 #' create_shifted_cases(example_confirmed, 7, 14, 7)
 create_shifted_cases <- function(reported_cases, shift, 
                                  smoothing_window, horizon) {
-  
   shifted_reported_cases <- data.table::copy(reported_cases)[,
               confirm := data.table::shift(confirm, n = shift,
                                            type = "lead", fill = NA)][,
-              confirm := data.table::frollmean(confirm, n = smoothing_window, 
-                                               align = "right", fill = 1)][,
+              confirm := runner::mean_run(confirm, k = smoothing_window, lag = -floor(smoothing_window / 2))][,
               confirm := data.table::fifelse(confirm == 0, 1, confirm)]
   
   ## Forecast trend on reported cases using the last week of data
@@ -202,7 +201,10 @@ create_rt_data <- function(rt = rt_opts(), breakpoints = NULL,
 #' create_gp_data(gp_opts(ls_mean = 14), data)
 create_backcalc_data <- function(backcalc = backcalc_opts) {
   data <- list(
-    rt_half_window = as.integer((backcalc$rt_window - 1) / 2)
+    rt_half_window = as.integer((backcalc$rt_window - 1) / 2),
+    backcalc_prior = ifelse(backcalc$prior == "none", 0,
+                            ifelse(backcalc$prior == "reports", 1, 
+                                   ifelse(backcalc$prior == "infections", 2, 0)))
   )
   return(data)
 }
@@ -396,40 +398,42 @@ create_initial_conditions <- function(data) {
   init_fun <- function(){
     out <- list()
     if (data$delays > 0) {
-      out$delay_mean <- array(purrr::map2_dbl(data$delay_mean_mean, data$delay_mean_sd, 
+      out$delay_mean <- array(purrr::map2_dbl(data$delay_mean_mean, data$delay_mean_sd * 0.1, 
                                               ~ rnorm(1, mean = .x, sd = .y)))
-      out$delay_sd <- array(purrr::map2_dbl(data$delay_sd_mean, data$delay_sd_sd, 
+      out$delay_sd <- array(purrr::map2_dbl(data$delay_sd_mean, data$delay_sd_sd * 0.1, 
                                             ~ rnorm(1, mean = .x, sd = .y)))
     }
     if (data$truncation > 0) {
       out$truncation_mean <- array(rnorm(1, mean = data$trunc_mean_mean,
-                                        sd = data$trunc_mean_sd))
-      out$truncation_sd <- array(rnorm(1, mean = data$trunc_sd_mean,
-                                       sd = data$trunc_sd_sd))
+                                        sd = data$trunc_mean_sd * 0.1))
+      out$truncation_sd <- array(truncnorm::rtruncnorm(1, 
+                                       a = 0,
+                                       mean = data$trunc_sd_mean,
+                                       sd = data$trunc_sd_sd * 0.1))
     }
     if (data$fixed == 0) {
       out$eta <- array(rnorm(data$M, mean = 0, sd = 0.1))
       out$rho <- array(rlnorm(1, meanlog = data$ls_meanlog, 
-                              sdlog = data$ls_sdlog))
+                              sdlog = data$ls_sdlog * 0.1))
       out$rho <- ifelse(out$rho > data$ls_max, data$ls_max - 0.001, 
                         ifelse(out$rho < data$ls_min, data$ls_min + 0.001, 
                                out$rho))
       out$alpha <- array(truncnorm::rtruncnorm(1, a = 0, mean = 0, sd = data$alpha_sd))
     }
     if (data$model_type == 1) {
-      out$rep_phi <- array(truncnorm::rtruncnorm(1, a = 0, mean = 0,  sd = 1))
+      out$rep_phi <- array(truncnorm::rtruncnorm(1, a = 0, mean = 0,  sd = 0.1))
     }
     if (data$estimate_r == 1) {
-      out$initial_infections <- array(rnorm(1, data$prior_infections, 0.2))
+      out$initial_infections <- array(rnorm(1, data$prior_infections, 0.02))
       if (data$seeding_time > 1) {
-        out$initial_growth <- array(rnorm(1, data$prior_growth, 0.1))
+        out$initial_growth <- array(rnorm(1, data$prior_growth, 0.01))
       }
       out$log_R <- array(rnorm(n = 1, mean = convert_to_logmean(data$r_mean, data$r_sd),
-                                      sd = convert_to_logsd(data$r_mean, data$r_sd)))
+                                      sd = convert_to_logsd(data$r_mean, data$r_sd) * 0.1))
       out$gt_mean <- array(truncnorm::rtruncnorm(1, a = 0, mean = data$gt_mean_mean,  
-                                                 sd = data$gt_mean_sd))
+                                                 sd = data$gt_mean_sd * 0.1))
       out$gt_sd <-  array(truncnorm::rtruncnorm(1, a = 0, mean = data$gt_sd_mean,
-                                                sd = data$gt_sd_sd))
+                                                sd = data$gt_sd_sd * 0.1))
       if (data$bp_n > 0) {
         out$bp_sd <- array(truncnorm::rtruncnorm(1, a = 0, mean = 0, sd = 0.1))
         out$bp_effects <- array(rnorm(data$bp_n, 0, 0.1))
@@ -438,7 +442,7 @@ create_initial_conditions <- function(data) {
     if (data$obs_scale == 1) {
       out$frac_obs = array(truncnorm::rtruncnorm(1, a = 0, 
                                                  mean = data$obs_scale_mean,
-                                                 sd = data$obs_scale_sd))
+                                                 sd = data$obs_scale_sd * 0.1))
     }
     return(out)
   }
