@@ -1,6 +1,7 @@
 #' Distribution Skeleton
 #'
-#' @description This function acts as a skeleton for a truncated distribution defined by 
+#' @description `r lifecycle::badge("questioning")`
+#' This function acts as a skeleton for a truncated distribution defined by 
 #' model type, maximum value and model parameters. It is designed to be used with the
 #' output from `get_dist`.
 #' @param n Numeric vector, number of samples to take (or days for the probability density).
@@ -120,7 +121,9 @@ dist_skel <- function(n, dist = FALSE, cum = TRUE, model,
 
 #' Fit an Integer Adjusted Exponential, Gamma or Lognormal distributions
 #'
-#'
+#' @description `r lifecycle::badge("stable")`
+#' Fits an integer adjusted exponential, gamma or lognormal distribution using 
+#' `stan`. 
 #' @param values Numeric vector of values
 #' @param samples Numeric, number of samples to take
 #' @param dist Character string, which distribution to fit. Defaults to exponential (`"exp"`) but
@@ -209,7 +212,8 @@ dist_fit <- function(values = NULL, samples = NULL, cores = 1,
 
 #' Generate a Gamma Distribution Definition Based on Parameter Estimates
 #'
-#' @description Generates a distribution definition when only parameter estimates 
+#' @description `r lifecycle::badge("soft-deprecated")`
+#' Generates a distribution definition when only parameter estimates 
 #' are available for gamma distributed parameters. See `rgamma` for distribution information.
 #' @param shape Numeric, shape parameter of the gamma distribution.
 #' @param shape_sd Numeric, standard deviation of the shape parameter.
@@ -264,7 +268,8 @@ gamma_dist_def <- function(shape, shape_sd,
 
 #' Generate a Log Normal Distribution Definition Based on Parameter Estimates
 #'
-#' @description Generates a distribution definition when only parameter estimates 
+#' @description `r lifecycle::badge("soft-deprecated")`
+#' Generates a distribution definition when only parameter estimates 
 #' are available for log normal distributed parameters. See `rlnorm` for distribution information.
 #' @param mean Numeric, log mean parameter of the gamma distribution.
 #' @param mean_sd Numeric, standard deviation of the log mean parameter.
@@ -329,7 +334,12 @@ lognorm_dist_def <- function(mean, mean_sd,
   
 #' Fit a Subsampled Bootstrap to Integer Values and Summarise Distribution Parameters
 #'
-#' @param values Numeric vector of integer values.
+#' @description `r lifecycle::badge("stable")`
+#' Fits an integer adjusted distribution to a subsampled bootstrap of data and then integrates 
+#' the posterior samples into a single set of summary statistics. Can be used to generate a robust
+#' reporting delay that accounts for the fact the underlying delay likely varies over time or that 
+#' the size of the available reporting delay sample may not be representative of the current case load.
+#' @param values Integer vector of values.
 #' @param dist Character string, which distribution to fit. Defaults to lognormal (`"lognormal"`) but
 #' gamma (`"gamma"`) is also supported.
 #' @param verbose Logical, defaults to `FALSE`. Should progress messages be printed
@@ -420,9 +430,31 @@ bootstrapped_dist_fit <- function(values,  dist = "lognormal",
   return(out)
 }
 
+#' Estimate a Delay Distribution
+#'
+#' @description `r lifecycle::badge("maturing")`
+#' Estimate a log normal delay distribution from a vector of integer delays. 
+#' Currently this function is a simple wrapper for `bootstrapped_dist_fit`. 
+#' @param delays Integer vector of delays
+#' @param ... Arguments to pass to internal methods.
+#' @return A list summarising the bootstrapped distribution
+#' @export
+#' @seealso bootstrapped_dist_fit
+#' @examples
+#' \donttest{
+#' delays <- rlnorm(500, log(5), 1)
+#' estimate_delay(delays, samples = 1000, bootstraps = 10)
+#'}
+estimate_delay <- function(delays, ...) {
+  bootstrapped_dist_fit(values = delays, 
+                        dist = "lognormal", ...)
+}
 
 #' Approximate Sampling a Distribution using Counts
 #'
+#' @description `r lifecycle::badge("soft-deprecated")`
+#' Convolves cases by a PMF function. This function will soon be removed or replaced with a 
+#' more robust `stan` implementation.
 #' @param cases A dataframe of cases (in date order) with the following variables:
 #' `date` and `cases`. 
 #' @param max_value Numeric, maximum value to allow. Defaults to 120 days
@@ -443,7 +475,7 @@ bootstrapped_dist_fit <- function(values,  dist = "lognormal",
 #' @importFrom data.table data.table setorder
 #' @importFrom lubridate days
 #' @examples
-#' cases <- EpiNow2::example_confirmed
+#' cases <- example_confirmed
 #' cases <- cases[, cases := as.integer(confirm)] 
 #' print(cases)
 #' 
@@ -563,6 +595,12 @@ sample_approx_dist <- function(cases = NULL,
 
 #' Tune an Inverse Gamma to Achieve the Target Truncation
 #'
+#' @description `r lifecycle::badge("questioning")`
+#' Allows an inverse gamma distribution to be. tuned so that less than 0.01 of its 
+#' probability mass function falls outside of the specified 
+#' bounds. This is required when using an inverse gamma prior, for example for a 
+#' Gaussian process. As no inverse gamma priors are currently in use and this function 
+#' has some stability issues it may be deprecated at a later date.
 #' @param lower Numeric, defaults to 2. Lower truncation bound.
 #' @param upper Numeric, defaults to 21. Upper truncation bound.
 #'
