@@ -4,17 +4,19 @@
 #' Uses a non-parametric approach to reconstruct cases by date of infection from reported 
 #' cases. It uses either a generative Rt model or non-parametric back calculation to estimate underlying
 #' latent infections and then maps these infections to observed cases via uncertain reporting delays and a flexible
-#' observation model. See the examples and function arguments for the details of all options. The default settings
-#'  may not be sufficient for your use case so the number of warmup samples (`stan_args = list(warmup)`) may need to
-#'  be increased as may the overall number of samples. Follow the links provided by any warnings messages to diagnose 
-#'  issues with the MCMC fit. It is recommended to explore several of the Rt estimation approaches supported as not all 
-#'  of them may be suited to users own use cases. 
+#' observation model. See the examples and function arguments for the details of all options. The default settings 
+#' may not be sufficient for your use case so the number of warmup samples (`stan_args = list(warmup)`) may need to 
+#' be increased as may the overall number of samples. Follow the links provided by any warnings messages to diagnose 
+#' issues with the MCMC fit. It is recommended to explore several of the Rt estimation approaches supported as not all 
+#' of them may be suited to users own use cases. See [here](https://gist.github.com/seabbs/163d0f195892cde685c70473e1f5e867) 
+#' for an example of using `estimate_infections` within the `epinow` wrapper to estimate Rt for Covid-19 in a country from 
+#' the ECDC data source.
 #' @param reported_cases A data frame of confirmed cases (confirm) by date (date). confirm must be integer and date must be 
 #' in date format.
 #' @param generation_time A list containing the mean, standard deviation of the mean (mean_sd), 
 #' standard deviation (sd), standard deviation of the standard deviation and the maximum allowed value for the
 #' generation time (assuming a gamma distribution).
-#' @param delays A call to `delay_opts` defining delay distributions and options. See the documentation of `delay_opts` 
+#' @param delays A call to `delay_opts()` defining delay distributions and options. See the documentation of `delay_opts()` 
 #' and the examples below for details.
 #' @param horizon Numeric, defaults to 7. Number of days into the future to forecast.
 #' @param verbose Logical, defaults to `TRUE` when used interactively and otherwise `FALSE`. Should verbose debug progress messages be printed. Corresponds to the "DEBUG" level from 
@@ -33,7 +35,7 @@
 #' @importFrom futile.logger flog.threshold flog.warn flog.debug
 #' @examples
 #' \donttest{
-#' #set number of cores to use
+#' # set number of cores to use
 #' options(mc.cores = ifelse(interactive(), 4, 1))
 #' # get example case counts
 #' reported_cases <- example_confirmed[1:60]
@@ -49,7 +51,8 @@
 #' # here we assume that the observed data is truncated by the same delay as 
 #' def <- estimate_infections(reported_cases, generation_time = generation_time,
 #'                            delays = delay_opts(incubation_period, reporting_delay),
-#'                            rt = rt_opts(prior = list(mean = 2, sd = 0.1)))
+#'                            rt = rt_opts(prior = list(mean = 2, sd = 0.1)),
+#'                            stan = stan_opts(control = list(adapt_delta = 0.95)))
 #' # real time estimates
 #' summary(def)
 #' # summary plot
@@ -88,10 +91,16 @@
 #' plot(trunc) 
 #' 
 #' # using back calculation (combined here with under reporting)
+#' # this model is in the order of 10 ~ 100 faster than the gaussian process method
+#' # it is likely robust for retrospective Rt but less reliable for real time estimates
+#' # the width of the prior window controls the reliance on observed data and can be 
+#' # optionally switched off using backcalc_opts(prior = "none"), see ?backcalc_opts for 
+#' # other options
 #' backcalc <- estimate_infections(reported_cases, generation_time = generation_time,
 #'                                 delays = delay_opts(incubation_period, reporting_delay),
-#'                                 rt = NULL, backcalc = backcalc_opts(rt_window = 1),
-#'                                 obs = obs_opts(scale = list(mean = 0.4, sd = 0.05)))
+#'                                 rt = NULL, backcalc = backcalc_opts(),
+#'                                 obs = obs_opts(scale = list(mean = 0.4, sd = 0.05)),
+#'                                 horizon = 0)
 #' plot(backcalc)
 #'                            
 #' # Rt projected into the future using the Gaussian process
@@ -111,8 +120,7 @@
 #' # stationary Rt assumption (likely to provide biased real-time estimates)
 #' stat <- estimate_infections(reported_cases, generation_time = generation_time,
 #'                             delays = delay_opts(incubation_period, reporting_delay),
-#'                             rt = rt_opts(prior = list(mean = 2, sd = 0.1),
-#'                                          gp_on = "R0"))
+#'                             rt = rt_opts(prior = list(mean = 2, sd = 0.1), gp_on = "R0"))
 #' plot(stat)
 #'        
 #' # no gaussian process (i.e fixed Rt assuming no breakpoints)
@@ -205,24 +213,32 @@ estimate_infections <- function(reported_cases,
                            backcalc = backcalc,
                            shifted_cases = shifted_cases$confirm,
                            horizon = horizon)
- 
+  
   # Set up default settings 
   args <- create_stan_args(stan = stan,
                            data = data,
                            init = create_initial_conditions(data),
                            verbose = verbose)
   
+  # Initialise fitting by using a previous fit or fitting to cumulative cases
+  if (!is.null(args$init_fit)) {
+    if (!("stanfit" %in% class(args$init_fit))) {
+      if (args$init_fit %in% "cumulative") {
+        args$init_fit <- init_cumulative_fit(args, warmup = 50, samples = 50, 
+                                             id = id, verbose = FALSE)
+      }
+    }
+    args$init <- extract_inits(args$init_fit, current_inits = args$init, 
+                               exclude_list = c("initial_infections", "initial_growth"),
+                               samples = 50)
+    args$init_fit <- NULL
+  }
   # Fit model
   if (args$method == "sampling") {
-    fit <- fit_model_with_nuts(args,
-                               future = args$future,
-                               max_execution_time = args$max_execution_time,
-                               verbose = verbose,
-                               id = id)
+    fit <- fit_model_with_nuts(args, future = args$future,
+                               max_execution_time = args$max_execution_time, id = id)
   }else if (args$method == "vb"){
-    fit <- fit_model_with_vb(args,
-                             verbose = verbose,
-                             id = id)
+    fit <- fit_model_with_vb(args, id = id)
   }
   # Extract parameters of interest from the fit
   out <- extract_parameter_samples(fit, data, 
@@ -254,6 +270,61 @@ estimate_infections <- function(reported_cases,
 }
 
 
+#' Generate initial conditions by fitting to cumulative cases
+#'
+#' @description `r lifecycle::badge("experimental")`
+#' Fits a model to cumulative cases. This may be a useful approach to initialising 
+#' a full model fit for certain data sets where the sampler gets stuck or cannot easily
+#' be initialised as fitting to cumulative cases changes the shape of the posterior
+#' distribution. In `estimate_infections()`, `epinow()` and `regional_epinow()` this option can be
+#' engaged by setting `stan_opts(init_fit = "cumulative")`.
+#' 
+#' This implementation is based on the approach taken in [epidemia](https://github.com/ImperialCollegeLondon/epidemia/)
+#' authored by James Scott.
+#' @param samples Numeric, defaults to 50. Number of posterior samples.
+#' @param warmup Numeric, defaults to 50. Number of warmup samples.
+#' @param verbose Logical, should fitting progress be returned. Defaults to `FALSE`.
+#' @inheritParams create_initial_conditions
+#' @importFrom rstan sampling
+#' @importFrom futile.logger flog.debug
+#' @importFrom utils capture.output
+#' @inheritParams fit_model_with_nuts
+#' @return A stanfit object
+init_cumulative_fit <- function(args, samples = 50, warmup = 50,
+                                id = "init", verbose = FALSE) { 
+  futile.logger::flog.debug("%s: Fitting to cumulative data to initialise chains", id,
+                            name = "EpiNow2.epinow.estimate_infections.fit")
+  # copy main run settings and override to use only 100 iterations and a single chain
+  initial_args <- list(
+    object = args$object,
+    data = args$data,
+    init = args$init,
+    iter = samples + warmup,
+    warmup = warmup,
+    chains = 1,
+    cores = 2,
+    open_progress = FALSE,
+    show_messages = FALSE,
+    control = list(adapt_delta = 0.9, max_treedepth = 13),
+    refresh = ifelse(verbose, 50, -1)
+  )
+  # change observations to be cumulative in order to protect against noise and give 
+  # an approximate fit (though for Rt constrained to be > 1)
+  initial_args$data$cases <- cumsum(initial_args$data$cases)
+  initial_args$data$shifted_cases <- cumsum(initial_args$data$shifted_cases)
+
+  # initial fit
+  if (verbose) {
+    fit <- do.call(rstan::sampling, initial_args)
+  }else{
+    out <- tempfile(tmpdir = tempdir(check = TRUE))
+    capture.output({fit <- do.call(rstan::sampling, initial_args)}, 
+                    type = c("output", "message"), split = FALSE,
+                    file = out)
+  }
+  return(fit)
+}
+
 #' Fit a Stan Model using the NUTs sampler
 #'
 #' @description `r lifecycle::badge("maturing")`
@@ -265,7 +336,6 @@ estimate_infections <- function(reported_cases,
 #'     Results will still be returned as long as at least 2 chains complete successfully within the timelimit. 
 #' @param id A character string used to assign logging information on error. Used by `regional_epinow` 
 #' to assign errors to regions. Alter the default to run with error catching.
-#' @param verbose Logical, defaults to `FALSE`. Should verbose progress information be returned.
 #' @importFrom futile.logger flog.debug flog.info flog.error
 #' @importFrom R.utils withTimeout
 #' @importFrom future.apply future_lapply
@@ -273,19 +343,15 @@ estimate_infections <- function(reported_cases,
 #' @importFrom rstan sflist2stanfit sampling
 #' @importFrom rlang abort cnd_muffle
 #' @return A stan model object
-fit_model_with_nuts <- function(args, future = FALSE, max_execution_time = Inf, 
-                                id = "stan", verbose = FALSE) {
+fit_model_with_nuts <- function(args, future = FALSE, max_execution_time = Inf, id = "stan") {
   args$method <- NULL
   args$max_execution_time <- NULL
   args$future <- NULL
   
-  if (verbose) {
-    futile.logger::flog.debug(paste0("%s: Running in exact mode for ", ceiling(args$iter - args$warmup) * args$chains," samples (across ", args$chains,
-                                     " chains each with a warm up of ", args$warmup, " iterations each) and ",
-                                     args$data$t," time steps of which ", args$data$horizon, " are a forecast"), 
+  futile.logger::flog.debug(paste0("%s: Running in exact mode for ", ceiling(args$iter - args$warmup) * args$chains," samples (across ", args$chains,
+                                   " chains each with a warm up of ", args$warmup, " iterations each) and ",
+                                    args$data$t," time steps of which ", args$data$horizon, " are a forecast"), 
                               id, name = "EpiNow2.epinow.estimate_infections.fit")
-  }
-  
   
   if (exists("stuck_chains", args)) {
     stuck_chains <- args$stuck_chains
@@ -330,7 +396,7 @@ fit_model_with_nuts <- function(args, future = FALSE, max_execution_time = Inf,
                      catch = !id %in% c("estimate_infections", "epinow"))
     if (stuck_chains > 0) {fit <- NULL}
     if (is.null(fit)) {
-      rlang::abort("model fitting was timed out - try increasing the max_execution_time")
+      rlang::abort("model fitting was timed out or failed")
     }
   }else{
     chains <- args$chains
@@ -373,14 +439,12 @@ fit_model_with_nuts <- function(args, future = FALSE, max_execution_time = Inf,
 #' @importFrom rstan vb
 #' @importFrom rlang abort
 #' @return A stan model object
-fit_model_with_vb <- function(args, future = FALSE, id = "stan", verbose = FALSE) {
+fit_model_with_vb <- function(args, future = FALSE, id = "stan") {
   args$method <- NULL
-  if (verbose) {
-    futile.logger::flog.debug(paste0("%s: Running in approximate mode for ", args$iter, " iterations (with ", args$trials, " attempts). Extracting ",
-                                     args$output_samples, " approximate posterior samples for ", args$data$t," time steps of which ",
-                                     args$data$horizon, " are a forecast"),
-                              id, name = "EpiNow2.epinow.estimate_infections.fit")
-  }
+  futile.logger::flog.debug(paste0("%s: Running in approximate mode for ", args$iter, " iterations (with ", args$trials, " attempts). Extracting ",
+                                   args$output_samples, " approximate posterior samples for ", args$data$t," time steps of which ",
+                                   args$data$horizon, " are a forecast"),
+                            id, name = "EpiNow2.epinow.estimate_infections.fit") 
   
   if (exists("trials", args)) {
     trials <- args$trials
@@ -400,7 +464,6 @@ fit_model_with_vb <- function(args, future = FALSE, id = "stan", verbose = FALSE
     return(fit)
   }
   safe_vb <- purrr::safely(fit_vb)
-  
   fit <- NULL
   current_trials <- 0
   
