@@ -51,12 +51,12 @@ summarise_results <- function(regions,
     estimates <- summaries
   }
 
-  estimates <- data.table::rbindlist(estimates, idcol = "region")
+  estimates <- data.table::rbindlist(estimates, idcol = "region", fill = TRUE)
   numeric_estimates  <- 
     data.table::copy(estimates)[measure %in% c("New confirmed cases by infection date",
                                                "Effective reproduction no.")][,
               .(data.table::data.table(region, measure, estimate), 
-                data.table::rbindlist(numeric_estimate))][,
+                data.table::rbindlist(numeric_estimate, fill = TRUE))][,
               metric :=  factor(measure, levels = c("New confirmed cases by infection date",
                                                     "Effective reproduction no."))][, measure := NULL]
   
@@ -148,7 +148,7 @@ regional_summary <- function(regional_output = NULL,
                              max_plot = 10) {
     
   reported_cases <- data.table::setDT(reported_cases)
-  
+   
   if (is.null(summary_dir)) {
     futile.logger::flog.info("No summary directory specified so returning summary output")
     return_output <- TRUE
@@ -158,7 +158,7 @@ regional_summary <- function(regional_output = NULL,
 
   if (!is.null(results_dir) & !is.null(regional_output)) {
     stop("Only one of results_dir and regional_output should be specified")
-  }
+  } 
   
   if (is.null(regional_output)) {
     if (!is.null(results_dir)) {
@@ -177,6 +177,7 @@ regional_summary <- function(regional_output = NULL,
   # get estimates
   results <- get_regional_results(regional_output,
                                   results_dir = results_dir,
+                                  date = target_date,
                                   samples = FALSE,
                                   forecast = FALSE)
   
@@ -348,10 +349,10 @@ summarise_key_measures <- function(regional_results = NULL,
   }else{
     timeseries <- regional_results 
   }
-  summarise_variable <- function(df, dof = 0) {
+  summarise_variable <- function(df, dof = 2) {
     cols <- setdiff(names(df), c("region", "date", "type", "strat"))
     df[,(cols) := round(.SD, dof), .SDcols = cols]
-    data.table::setorderv(df, cols = cols)
+    data.table::setorderv(df, cols = c("region", "date", "type", "strat"))
     data.table::setnames(df, "region", type)
     return(df)
   }
@@ -395,7 +396,7 @@ summarise_key_measures <- function(regional_results = NULL,
 #' @return A data.table of region run times
 #' @export
 #' @importFrom data.table data.table fwrite
-#' @importFrom purrr map
+#' @importFrom purrr map safely
 #' @examples
 #' \donttest{
 #' # example delays
@@ -440,19 +441,18 @@ regional_runtimes <- function(regional_output = NULL,
     if (is.null(target_date)) {
       target_date <- "latest"
     }
+    safe_read <- purrr::safely(readRDS)
     regions <- get_regions(target_folder)
     timings <- data.table::data.table(
       region = regions,
-      time = unlist(purrr::map(regions, ~ readRDS(paste0(target_folder, 
-                                                         "/", .,"/", target_date,
-                                                         "/runtime.rds"))))
+      time = unlist(purrr::map(regions, ~ safe_read(paste0(target_folder,
+                                                           "/", .,"/", target_date,
+                                                           "/runtime.rds")))[[1]])
     )
   } 
-  
   if (!is.null(target_folder)) {
     data.table::fwrite(timings, paste0(target_folder, "/runtimes.csv"))
   }
-  
   if (return_output) {
     return(timings)
   }else{
