@@ -6,7 +6,8 @@ test_that("create_future_rt works as expected", {
     expect_equal(test$fixed, true$fixed)
   }
   
-  test_frt(EpiNow2:::create_future_rt(), list(fixed = FALSE, from = 0))
+  test_frt(EpiNow2:::create_future_rt(), list(fixed = TRUE, from = 0))
+  test_frt(EpiNow2:::create_future_rt("project"), list(fixed = FALSE, from = 0))
   test_frt(EpiNow2:::create_future_rt("est", 10), list(fixed = TRUE, from = -10))
   test_frt(EpiNow2:::create_future_rt(-3), list(fixed = TRUE, from = -3))
   test_frt(EpiNow2:::create_future_rt(3), list(fixed = TRUE, from = 3))
